# Changelog

## [0.2.0](https://www.github.com/NotANameServer/incipyt/compare/v0.1.0...v0.2.0) (2022-05-28)


### Features

* advanced logging configuration ([3f5e470](https://www.github.com/NotANameServer/incipyt/commit/3f5e470fd1336cbb5ccc65f2a50d054d344b8af1)), closes [#22](https://www.github.com/NotANameServer/incipyt/issues/22)
* crash when git is missing ([151f8a8](https://www.github.com/NotANameServer/incipyt/commit/151f8a8adca513556a4e21494e50379f561cef13))
* **setuptools:** specific var for python_requires ([42ce7be](https://www.github.com/NotANameServer/incipyt/commit/42ce7be70d55c6a0f321c26acc1477f0c18639ce)), closes [#31](https://www.github.com/NotANameServer/incipyt/issues/31)


### Bug Fixes

* **venv:** --upgrade-deps option missing on mint ([80b0bcf](https://www.github.com/NotANameServer/incipyt/commit/80b0bcfbee653b0530ede035daad15ebb12b099e)), closes [#27](https://www.github.com/NotANameServer/incipyt/issues/27)

## 0.1.0 (2022-04-27)


### Features

* Central Hierarchy + Environment design populated by Actions ([c6ba581](https://www.github.com/NotANameServer/incipyt/commit/c6ba5811dc4ac921d208e19ba5141c03fe227130))
* first proposal for TemplateDict internal ([682e437](https://www.github.com/NotANameServer/incipyt/commit/682e437171790389ee1acab345977154e55f8c07))
* improve TemplateDict use cases ([f120870](https://www.github.com/NotANameServer/incipyt/commit/f12087096c5a3d6daf6c1b00b546d6d1b87f9c9e))
* project initialization ([de1b463](https://www.github.com/NotANameServer/incipyt/commit/de1b4631d5cd0430c11ee558daf354343cb05e2d)), closes [#3](https://www.github.com/NotANameServer/incipyt/issues/3)
* system.Environement specifications as dict-like class ([e47029c](https://www.github.com/NotANameServer/incipyt/commit/e47029c5eb2e4e6a450329540401cde1fbdd4f96))
* TemplateList proxy for configuration ([48c25c9](https://www.github.com/NotANameServer/incipyt/commit/48c25c924f6cb0882a871c3a6b4d0939088808d5))
* Using click for interactive cli ([22188e7](https://www.github.com/NotANameServer/incipyt/commit/22188e7bbcb0011252fcd7bc80ae5515d6dce93a))


### Bug Fixes

* Cfg and TOML dumpers behaviors ([928d999](https://www.github.com/NotANameServer/incipyt/commit/928d999f82f95930c8479a874b534468ebd4eb38))
* miscellaneous text files for SetupTools ([9dbdac3](https://www.github.com/NotANameServer/incipyt/commit/9dbdac3b6f77dac337dfe750c9422c813947af13))
* remove dumpers instanciation classmethod ([9a8994a](https://www.github.com/NotANameServer/incipyt/commit/9a8994abae5b883469d7c5d281d2f99f30159608))
* remove unnecessary else branch ([9f850d9](https://www.github.com/NotANameServer/incipyt/commit/9f850d9c5f78226b26a230b49ada9c06f954de8e))
* solve click.argument issue with Path object for type arg ([68bc301](https://www.github.com/NotANameServer/incipyt/commit/68bc301137830f24943193ff1aabe2301c3d8fac))
* use proper syntax for named tuple ([4ff7193](https://www.github.com/NotANameServer/incipyt/commit/4ff71938eb3c220dfaad5e962e903ef182f7b112))
* various fixes ([f1334af](https://www.github.com/NotANameServer/incipyt/commit/f1334afa0838f3ffcccfd570ada315874c69eec0))
* windows compatibility ([686f8fb](https://www.github.com/NotANameServer/incipyt/commit/686f8fb0085474f3b23a159fd169788f37a577d6))


### Documentation

* improve utils docs ([aafff78](https://www.github.com/NotANameServer/incipyt/commit/aafff78356cca0976614384832b3f596bcd1c1c1))
* incipyt help message ([3ab6d16](https://www.github.com/NotANameServer/incipyt/commit/3ab6d16c0c6a2ae30ea0bcd10d91ea6d70ab80cd))
